@@ -2,10 +2,16 @@
 
 import hamcrest
 from hamcrest.core.base_matcher import BaseMatcher
+from hamcrest import assert_that, is_
 
 from internal import Method, InvocationContext, ANY_ARG, MockBase
 from exc import WrongApiUsage
 
+__all__ = ['called', 'called_with',
+           'never',
+           'verify', 'any_order_verify',
+           'assert_that', 'is_']
+
 
 class MethodCalled(BaseMatcher):
     any_time = hamcrest.greater_than(0)
@@ -20,7 +26,7 @@ class MethodCalled(BaseMatcher):
             raise WrongApiUsage(
                 "takes a double method (got %s instead)" % method)
 
-        return method.was_called(self.context, self._times)
+        return method._was_called(self.context, self._times)
 
     def describe_to(self, description):
         description.append_text('this call:\n')
@@ -31,7 +37,7 @@ class MethodCalled(BaseMatcher):
 
     def describe_mismatch(self, actual, description):
         description.append_text("calls that actually ocurred were:\n")
-        description.append_text(self.method.double.invocations.show(indent=10))
+        description.append_text(self.method.double._recorded.show(indent=10))
 
     def times(self, n):
         return MethodCalled(self.context, times=n)
@@ -68,37 +74,41 @@ class MockExpectInvocation(BaseMatcher):
 
     def _matches(self, mock):
         self.mock = mock
-        return self.invocation in mock.stubs
+        return self.invocation in mock._stubs
 
     def describe_to(self, description):
         description.append_text("these calls:\n")
-        description.append_text(self.mock.stubs.show(indent=10))
+        description.append_text(self.mock._stubs.show(indent=10))
 
     def describe_mismatch(self, actual, description):
         description.append_text("this call was not expected:\n")
         description.append_text(self.invocation.show(indent=10))
 
 
-class MockMeetsExpectations(BaseMatcher):
+class verify(BaseMatcher):
     def _matches(self, mock):
         if not isinstance(mock, MockBase):
             raise WrongApiUsage(
                 "takes Mock instance (got %s instead)" % mock)
 
         self.mock = mock
-        return mock.stubs == mock.invocations
+        return self._expectations_match()
+
+    def _expectations_match(self):
+        return self.mock._stubs == self.mock._recorded
 
     def describe_to(self, description):
         description.append_text("these calls:\n")
-        description.append_text(self.mock.stubs.show(indent=10))
+        description.append_text(self.mock._stubs.show(indent=10))
 
     def describe_mismatch(self, actual, description):
         description.append_text('calls that actually ocurred were:\n')
-        description.append_text(self.mock.invocations.show(indent=10))
+        description.append_text(self.mock._recorded.show(indent=10))
 
 
-def meets_expectations():
-    return MockMeetsExpectations()
+class any_order_verify(verify):
+    def _expectations_match(self):
+        return sorted(self.mock._stubs) == sorted(self.mock._recorded)
 
 
 # just aliases
